@@ -59,11 +59,12 @@
 #' - see the Stephens (2016) reference below for citation;
 #' \code{"normal"} is the 2014 DESeq2 shrinkage estimator using a Normal prior;
 #' @param lfcThreshold a non-negative value which specifies a log2 fold change
-#' threshold (as in \code{\link{results}}). This can be used in conjunction with
-#' \code{normal} and \code{apeglm}, where it will produce new p-values or
+#' threshold (as in \code{\link{results}}). This can be used with any
+#' shrinkage \code{type}. It will produce new p-values or
 #' s-values testing whether the LFC is greater in absolute value than the threshold.
-#' The s-values returned in combination with \code{apeglm} provide the probability
-#' of FSOS events, "false sign or small", among the tests with equal or smaller s-value
+#' The s-values returned in combination with \code{apeglm} or \code{ashr}
+#' provide the probability of FSOS events, "false sign or small",
+#' among the tests with equal or smaller s-value
 #' than a given gene's s-value, where "small" is specified by \code{lfcThreshold}.
 #' @param svalue logical, should p-values and adjusted p-values be replaced
 #' with s-values when using \code{apeglm} or \code{ashr}. s-values provide the probability
@@ -163,6 +164,9 @@ lfcShrink <- function(dds, coef, contrast, res,
       stop("first run DESeq() before running lfcShrink()")
     }
   }
+  if (returnList) {
+    stopifnot(type %in% c("apeglm","ashr"))
+  }
   betaPrior <- attr(dds,"betaPrior")
   if (!is.null(betaPrior) && betaPrior) {
     stop("lfcShrink() should be used downstream of DESeq() with betaPrior=FALSE (the default)")
@@ -315,18 +319,7 @@ Reference: https://doi.org/10.1093/bioinformatics/bty895")
       res[[column]] <- res.shr[[column]]
     }
     mcols(res,use.names=TRUE)[change.cols,"description"] <- mcols(res.shr,use.names=TRUE)[change.cols,"description"]
-    
-    deseq2.version <- packageVersion("DESeq2")
-    # stash lfcThreshold
-    metadata(res)[["lfcThreshold"]] <- lfcThreshold
-    priorInfo(res) <- list(type="normal",
-                           package="DESeq2",
-                           version=deseq2.version,
-                           betaPriorVar=betaPriorVar)
-
-    res <- resultsFormatSwitch(object=dds, res=res, format=format, saveCols=saveCols)
-    return(res)
-    
+        
   } else if (type == "apeglm") {
 
     ############
@@ -420,7 +413,7 @@ Reference: https://doi.org/10.1093/bioinformatics/bty895")
     stopifnot(nrow(fit$map) == nrow(dds))
     conv <- fit$diag[,"conv"]
     if (!all(conv[!is.na(conv)] == 0)) {
-      message("Some rows did not converge in finding the MAP")
+      message("some rows did not converge in finding the MAP")
     }
     res$log2FoldChange <- log2(exp(1)) * fit$map[,coefNum]
     res$lfcSE <- log2(exp(1)) * fit$sd[,coefNum]
@@ -440,18 +433,6 @@ Reference: https://doi.org/10.1093/bioinformatics/bty895")
     } else {
       res <- res[,c(1:3,5:6)]
     }
-    # stash lfcThreshold
-    metadata(res)[["lfcThreshold"]] <- lfcThreshold
-    priorInfo(res) <- list(type="apeglm",
-                           package="apeglm",
-                           version=packageVersion("apeglm"),
-                           prior.control=fit$prior.control)
-    res <- resultsFormatSwitch(object=dds, res=res, format=format, saveCols=saveCols)
-    if (returnList) {
-      return(list(res=res, fit=fit))
-    } else {
-      return(res)
-    }
 
   } else if (type == "ashr") {
 
@@ -466,8 +447,7 @@ Reference: https://doi.org/10.1093/bioinformatics/bty895")
     if (!quiet) message("using 'ashr' for LFC shrinkage. If used in published research, please cite:
     Stephens, M. (2016) False discovery rates: a new deal. Biostatistics, 18:2.
     https://doi.org/10.1093/biostatistics/kxw041")
-    
-    if (lfcThreshold > 0) message("lfcThreshold is not used by type='ashr'")
+
     betahat <- res$log2FoldChange
     sebetahat <- res$lfcSE
     fit <- ashr::ash(betahat, sebetahat,
@@ -476,27 +456,68 @@ Reference: https://doi.org/10.1093/bioinformatics/bty895")
     res$lfcSE <- fit$result$PosteriorSD
     mcols(res)$description[2] <- sub("MLE","MMSE",mcols(res)$description[2])
     mcols(res)$description[3] <- sub("standard error","posterior SD",mcols(res)$description[3])
-    if (svalue) {
-      coefAlphaSpaces <- sub(".*p-value: ","",mcols(res)$description[5])
-      res <- res[,1:3]
-      res$svalue <- fit$result$svalue
-      mcols(res)[4,] <- DataFrame(type="results",
-                                  description=paste("s-value:",coefAlphaSpaces))
-    } else {
-      res <- res[,c(1:3,5:6)]
-    }
-    # stash lfcThreshold
-    metadata(res)[["lfcThreshold"]] <- lfcThreshold
-    priorInfo(res) <- list(type="ashr",
-                           package="ashr",
-                           version=packageVersion("ashr"),
-                           fitted_g=fit$fitted_g)
-    res <- resultsFormatSwitch(object=dds, res=res, format=format, saveCols=saveCols)
-    if (returnList) {
-      return(list(res=res, fit=fit))
-    } else{
-      return(res)
-    }
 
+    # coefficient name (in words, with spaces)
+    coefAlphaSpaces <- sub(".*p-value: ","",mcols(res)$description[5])
+
+    # switch on whether LFC threshold is > 0
+    if (lfcThreshold == 0) {
+      if (svalue) {
+        res <- res[,1:3]
+        res$svalue <- fit$result$svalue
+      } else {
+        res <- res[,c(1:3,5:6)]
+      }
+    } else {
+      message(paste0("computing FSOS 'false sign or small' s-values (T=",round(lfcThreshold,3),")"))
+      # code contributed by Frederik Ziebell 2022
+      svalue <- TRUE
+      cdf_pos_lfc <- ashr::cdf_post(fit$fitted_g, lfcThreshold,
+                                    ashr::set_data(betahat, sebetahat))
+      cdf_neg_lfc <- ashr::cdf_post(fit$fitted_g, -lfcThreshold,
+                                    ashr::set_data(betahat, sebetahat))
+      lfsr <- ifelse(res$log2FoldChange > 0, cdf_pos_lfc, 1 - cdf_neg_lfc)
+      res$svalue <- apeglm_svalue(lfsr)
+    }
   }
+  
+  # add metadata column for svalue
+  if (svalue) {
+    mcols(res)[4,] <- DataFrame(
+      type="results",
+      description=paste("s-value:",coefAlphaSpaces))
+  }
+
+  # stash lfcThreshold and type/pkg details
+  metadata(res)[["lfcThreshold"]] <- lfcThreshold
+  pkg <- if (type == "normal") "DESeq2" else type
+  priorInfo(res) <- list(type=type,
+                         package=pkg,
+                         version=packageVersion(pkg))
+
+  # information on the fitted prior
+  if (type == "normal") {
+    priorInfo(res) <- c(priorInfo(res), list(betaPriorVar=betaPriorVar))
+  } else if (type == "apeglm") {
+    priorInfo(res) <- c(priorInfo(res), list(prior.control=fit$prior.control))
+  } else if (type == "ashr") {
+    priorInfo(res) <- c(priorInfo(res), list(fitted_g=fit$fitted_g))
+  }
+    
+  res <- resultsFormatSwitch(object=dds, res=res, format=format, saveCols=saveCols)
+
+  if (returnList) {
+    return(list(res=res, fit=fit))
+  } else {
+    return(res)
+  }
+
+}
+
+# copied from apeglm package to avoid extra package installation for ashr shrinkage
+apeglm_svalue <- function(lfsr) {
+  lfsr.sorted <- sort(lfsr, na.last = TRUE)
+  cumsum.idx <- seq_along(lfsr)
+  cumsum.lfsr <- cumsum(lfsr.sorted)
+  (cumsum.lfsr/cumsum.idx)[rank(lfsr, ties.method = "first", na.last = TRUE)]
 }
