@@ -84,12 +84,20 @@ plotDispEsts.DESeqDataSet <- function( object, ymin, CV=FALSE,
 #' @export
 setMethod("plotDispEsts", signature(object="DESeqDataSet"), plotDispEsts.DESeqDataSet)
 
-plotMA.DESeqDataSet <- function(object, alpha=.1, main="", xlab="mean of normalized counts", ylim, MLE=FALSE, ...) {
+plotMA.DESeqDataSet <- function(object, alpha=.1, main="",
+                                xlab="mean of normalized counts", ylim,
+                                colNonSig="gray60", colSig="blue", colLine="grey40",
+                                returnData=FALSE,
+                                MLE=FALSE, ...) {
     res <- results(object, ...)
     plotMA.DESeqResults(res, alpha=alpha, main=main, xlab=xlab, ylim=ylim, MLE=MLE)
 }
 
-plotMA.DESeqResults <- function(object, alpha, main="", xlab="mean of normalized counts", ylim, MLE=FALSE, ...) {
+plotMA.DESeqResults <- function(object, alpha, main="",
+                                xlab="mean of normalized counts", ylim,
+                                colNonSig="gray60", colSig="blue", colLine="grey40",
+                                returnData=FALSE,
+                                MLE=FALSE, ...) {
 
   sval <- "svalue" %in% names(object)
 
@@ -125,13 +133,20 @@ plotMA.DESeqResults <- function(object, alpha, main="", xlab="mean of normalized
   df <- data.frame(mean = object[["baseMean"]],
                    lfc = object[[lfc.col]],
                    isDE = isDE)
-  
-  if (missing(ylim)) {
-    plotMA(df, main=main, xlab=xlab, ...)
-  } else {
-    plotMA(df, main=main, xlab=xlab, ylim=ylim, ...)
+
+  if (returnData) {
+    return(df)
   }
 
+  if (missing(ylim)) {
+    plotMA(df,
+           colNonSig=colNonSig, colSig=colSig, colLine=colLine,
+           xlab=xlab, main=main, ...)
+  } else {
+    plotMA(df, ylim=ylim,
+           colNonSig=colNonSig, colSig=colSig, colLine=colLine,
+           xlab=xlab, main=main, ...)
+  }
 }
 
 #' MA-plot from base means and log fold changes
@@ -143,11 +158,12 @@ plotMA.DESeqResults <- function(object, alpha, main="", xlab="mean of normalized
 #' This function is essentially two lines of code: building a
 #' \code{data.frame} and passing this to the \code{plotMA} method
 #' for \code{data.frame} from the geneplotter package.
+#' The code was modified in version 1.28 to change from red to blue points
+#' for better visibility for users with color-blindness. The original plots
+#' can still be made via the use of \code{returnData=TRUE} and passing the
+#' resulting data.frame directly to \code{geneplotter::plotMA}.
 #' The code of this function can be seen with:
 #' \code{getMethod("plotMA","DESeqDataSet")}
-#' If users wish to modify the graphical parameters of the plot,
-#' it is recommended to build the data.frame in the
-#' same manner and call \code{plotMA}.
 #' If the \code{object} contains a column \code{svalue} then these
 #' will be used for coloring the points (with a default \code{alpha=0.005}).
 #'
@@ -160,15 +176,19 @@ plotMA.DESeqResults <- function(object, alpha, main="", xlab="mean of normalized
 #' or a \code{DESeqDataSet} processed by \code{\link{DESeq}}, or the
 #' individual functions \code{\link{nbinomWaldTest}} or \code{\link{nbinomLRT}}
 #' @param alpha the significance level for thresholding adjusted p-values
+#' @param main optional title for the plot
+#' @param xlab optional defaults to "mean of normalized counts"
+#' @param ylim optional y limits
+#' @param colNonSig color to use for non-significant data points
+#' @param colSig color to use for significant data points
+#' @param colLine color to use for the horizontal (y=0) line
+#' @param returnData logical, whether to return the data.frame used for plotting
 #' @param MLE if \code{betaPrior=TRUE} was used,
 #' whether to plot the MLE (unshrunken estimates), defaults to FALSE.
 #' Requires that \code{\link{results}} was run with \code{addMLE=TRUE}.
 #' Note that the MLE will be plotted regardless of this argument,
 #' if DESeq() was run with \code{betaPrior=FALSE}. See \code{\link{lfcShrink}}
 #' for examples on how to plot shrunken log2 fold changes.
-#' @param main optional title for the plot
-#' @param xlab optional defaults to "mean of normalized counts"
-#' @param ylim optional y limits
 #' @param ... further arguments passed to \code{plotMA} if object
 #' is \code{DESeqResults} or to \code{\link{results}} if object is
 #' \code{DESeqDataSet}
