@@ -126,6 +126,11 @@ ddsSE
 keep <- rowSums(counts(dds)) >= 10
 dds <- dds[keep,]
 
+## ----eval=FALSE---------------------------------------------------------------
+#  # unevaluated chunk...
+#  keep <- rowSums(counts(dds) >= 10) >= X
+#  dds <- dds[keep,]
+
 ## ----factorlvl----------------------------------------------------------------
 dds$condition <- factor(dds$condition, levels = c("untreated","treated"))
 
@@ -300,6 +305,10 @@ ggplot(pcaData, aes(PC1, PC2, color=condition, shape=type)) +
 #  dds <- estimateDispersions(dds)
 #  dds <- nbinomWaldTest(dds)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  dds <- estimateSizeFactors(dds, controlGenes=ctrlGenes)
+#  dds <- DESeq(dds)
+
 ## ----simpleContrast, eval=FALSE-----------------------------------------------
 #  results(dds, contrast=c("condition","C","B"))
 
@@ -350,6 +359,11 @@ resApeT <- lfcShrink(dds, coef=2, type="apeglm", lfcThreshold=1)
 plotMA(resApeT, ylim=c(-3,3), cex=.8)
 abline(h=c(-1,1), col="dodgerblue", lwd=2)
 
+## ----ashThresh----------------------------------------------------------------
+resAshT <- lfcShrink(dds, coef=2, type="ashr", lfcThreshold=1)
+plotMA(resAshT, ylim=c(-3,3), cex=.8)
+abline(h=c(-1,1), col="dodgerblue", lwd=2)
+
 ## -----------------------------------------------------------------------------
 condition <- factor(rep(c("A","B","C"),each=2))
 model.matrix(~ condition)
